@@ -20,11 +20,6 @@ class PropertiesDialog(QDialog):
         self.setMinimumWidth(360)
         self.resize(360, self.height())
 
-        # Color dialog (separated from the window)
-        self.color_select = QColorDialog()
-        self.color_select.setOption(QColorDialog.DontUseNativeDialog, True)
-        self.color_select.setWindowFlags(Qt.WindowStaysOnTopHint)
-
         # Labels (top)
         self.label_x = QLabel('X coordinate')
         self.label_y = QLabel('Y coordinate')
@@ -54,19 +49,21 @@ class PropertiesDialog(QDialog):
         self.doubleSpinBox_alpha = self._generate_spinbox(lower=0.0, upper=1.0, step=0.1)
         self.doubleSpinBox_vmin = self._generate_spinbox()
         self.doubleSpinBox_vmax = self._generate_spinbox()
-        self.comboBox_markers = QComboBox()
-        self.doubleSpinBox_pointsize = self._generate_spinbox(lower=0.0)
-        self.checkBox_recalculate = QCheckBox('Enable auto-calculation', self)
 
         # Colormap
         self.pushButton_color_start = self._generate_colored_button('Low', [1.0, 0.0, 0.0])
         self.pushButton_color_end = self._generate_colored_button('High', [0.0, 0.0, 1.0])
+        self.doubleSpinBox_pointsize = self._generate_spinbox(lower=0.0)
+        self.comboBox_markers = QComboBox(self)
 
         # Block size
         self.doubleSpinBox_xsize = self._generate_spinbox(lower=0.0)
         self.doubleSpinBox_ysize = self._generate_spinbox(lower=0.0)
         self.doubleSpinBox_zsize = self._generate_spinbox(lower=0.0)
 
+        # Recalculate
+        self.checkBox_recalculate = QCheckBox('Enable auto-calculation', self)
+
         # ButtonBox (Accept/Reject)
         self.buttonBox = QDialogButtonBox(self)
         self.buttonBox.setOrientation(Qt.Horizontal)
@@ -178,17 +175,20 @@ class PropertiesDialog(QDialog):
         return button
 
     def _spawn_color_dialog(self, button: QAbstractButton) -> None:
-        # Regenerate connections
-        self.color_select.disconnect()
-        self.color_select.accepted.connect(
-            lambda *args: self._update_button_color(button, self._qcolor_to_color(self.color_select.currentColor())))
+        # Color dialog (separated from the window)
+        color_select = QColorDialog()
+        color_select.setOption(QColorDialog.DontUseNativeDialog, True)
+        color_select.setWindowFlags(Qt.WindowStaysOnTopHint)
+
+        color_select.accepted.connect(
+            lambda *args: self._update_button_color(button, self._qcolor_to_color(color_select.currentColor())))
 
         # Update current color
         color = self._parse_style_sheet(button.styleSheet())
         qcolor = self._color_to_qcolor(color)
-        self.color_select.setCurrentColor(qcolor)
+        color_select.setCurrentColor(qcolor)
 
-        self.color_select.show()
+        color_select.show()
 
     def _update_button_color(self, button: QAbstractButton, color: Color) -> None:
         button.setStyleSheet(f'background-color:{color.get_web()}')
