@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-#  Copyright (c) 2019-2021 Gabriel Sanhueza.
+#  Copyright (c) 2019-2023 Gabriel Sanhueza.
 #
 #  Distributed under the MIT License.
 #  See LICENSE for more info.
@@ -418,7 +418,7 @@ class IntegrableViewer(QOpenGLWidget):
         counter = []
 
         def start_animation():
-            timer.start(milliseconds / steps)
+            timer.start(milliseconds // steps)
             self.signal_animation_started.emit()
 
         def update_animation():
